schema/schema_options library

Classes

DartType
Define a Dart type.
GeneratorOptions
This generator options, gathered from build.yaml file.
ScalarMap
Maps a GraphQL scalar to a Dart type.
SchemaMap
Maps a GraphQL schema to queries files. Output files are automatically generated in generated directories based on the queries_glob pattern and detected operation type.

Enums

NamingScheme
The naming scheme to be used on generated classes names.